Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func MergeByKey ¶
func MergeByKey[T any, K comparable](base, additional []T, key func(T) K) []T
MergeByKey appends items from additional into base when their key is not yet present.
func NewCopilotLogIterator ¶
NewCopilotLogIterator creates an iterator for an events.jsonl formatted log
func ResolvePaths ¶
ResolvePaths resolves a list of paths relative to a base directory. Absolute paths are returned unchanged, relative paths are resolved relative to the base directory.
func SessionToSlog ¶
func SessionToSlog(event copilot.SessionEvent)
SessionToSlog tries to be a low-overhead method for dumping out any session events coming from the copilot client to slog. It's safe to add this to your copilot session instances, in their copilot.Session.On handler.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.